@@ -51,7 +51,7 @@ XS(end_locker) {
 	XSRETURN_EMPTY;
 }
 
-void end_unlocker(pTHX_ void* ptr) {
+void end_unlocker() {
 	perl_mutex* mutex = get_shutdown_mutex();
 	MUTEX_UNLOCK(mutex);
 	/* wait for all threads to exit? */
@@ -71,7 +71,7 @@ void global_init(pTHX) {
 
 		/* This is a nasty trick to make sure locking is performed during part of the destruct */
 		newXS("END", end_locker, __FILE__);
-		Perl_call_atexit(aTHX_ end_unlocker, NULL);
+		atexit(end_unlocker);
 	}
 }
 
@@ -92,7 +92,7 @@ void mthread_destroy(mthread* thread) {
 	MUTEX_UNLOCK(&threads.lock);
 }
 
-static mthread* S_get_thread(pTHX_ UV thread_id) {
+static inline mthread* S_get_thread(pTHX_ UV thread_id) {
 	if (thread_id >= threads.current || threads.objects[thread_id] == NULL)
 		Perl_croak(aTHX_  "Thread %"UVuf" doesn't exist", thread_id);
 	return threads.objects[thread_id];
@@ -107,7 +107,7 @@ UV queue_alloc(IV linked_to) {
 	return resource_addobject(&queues, queue);
 }
 
-static message_queue* S_get_queue(pTHX_ UV queue_id) {
+static inline message_queue* S_get_queue(pTHX_ UV queue_id) {
 	if (queue_id >= queues.current || queues.objects[queue_id] == NULL)
 		Perl_croak(aTHX_  "queue %"UVuf" doesn't exist", queue_id);
 	return queues.objects[queue_id];
